package com.sun.java.swing.plaf.motif;

import java.awt.FontMetrics;
import java.awt.Point;
import sun.swing.SwingUtilities2;
import javax.swing.JPopupMenu;
import java.awt.Font;
import javax.swing.JInternalFrame;
import java.awt.Rectangle;
import javax.swing.JComponent;
import java.awt.Dimension;
import javax.swing.JMenuBar;
import javax.swing.ButtonModel;
import javax.swing.JButton;
import javax.swing.AbstractButton;
import java.awt.Insets;
import java.awt.Component;
import javax.swing.UIManager;
import javax.swing.plaf.UIResource;
import javax.swing.border.AbstractBorder;
import java.awt.Color;
import java.awt.Graphics;

public class MotifBorders
{
    public MotifBorders() {
    }
    
    public static void drawBezel(Graphics graphics, int n, int n2, int n3, int n4, boolean b, boolean b2, Color color, Color color2, Color color3, Color color4) {
        Color color5 = graphics.getColor();
        graphics.translate(n, n2);
        if (b) {
            if (b2) {
                graphics.setColor(color4);
                graphics.drawRect(0, 0, n3 - 1, n4 - 1);
            }
            graphics.setColor(color);
            graphics.drawRect(1, 1, n3 - 3, n4 - 3);
            graphics.setColor(color2);
            graphics.drawLine(2, n4 - 3, n3 - 3, n4 - 3);
            graphics.drawLine(n3 - 3, 2, n3 - 3, n4 - 4);
        }
        else {
            if (b2) {
                graphics.setColor(color4);
                graphics.drawRect(0, 0, n3 - 1, n4 - 1);
                graphics.setColor(color2);
                graphics.drawLine(1, 1, 1, n4 - 3);
                graphics.drawLine(2, 1, n3 - 4, 1);
                graphics.setColor(color);
                graphics.drawLine(2, n4 - 3, n3 - 3, n4 - 3);
                graphics.drawLine(n3 - 3, 1, n3 - 3, n4 - 4);
                graphics.setColor(color3);
                graphics.drawLine(1, n4 - 2, n3 - 2, n4 - 2);
                graphics.drawLine(n3 - 2, n4 - 2, n3 - 2, 1);
            }
            else {
                graphics.setColor(color2);
                graphics.drawLine(1, 1, 1, n4 - 3);
                graphics.drawLine(2, 1, n3 - 4, 1);
                graphics.setColor(color);
                graphics.drawLine(2, n4 - 3, n3 - 3, n4 - 3);
                graphics.drawLine(n3 - 3, 1, n3 - 3, n4 - 4);
                graphics.setColor(color3);
                graphics.drawLine(1, n4 - 2, n3 - 2, n4 - 2);
                graphics.drawLine(n3 - 2, n4 - 2, n3 - 2, 0);
            }
            graphics.translate(-n, -n2);
        }
        graphics.setColor(color5);
    }
    
    public static class BevelBorder extends AbstractBorder implements UIResource
    {
        private Color darkShadow;
        private Color lightShadow;
        private boolean isRaised;
        
        public BevelBorder(boolean isRaised, Color darkShadow, Color lightShadow) {
            this.darkShadow = UIManager.getColor("controlShadow");
            this.lightShadow = UIManager.getColor("controlLtHighlight");
            this.isRaised = isRaised;
            this.darkShadow = darkShadow;
            this.lightShadow = lightShadow;
        }
        
        @Override
        public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
            graphics.setColor(this.isRaised ? this.lightShadow : this.darkShadow);
            graphics.drawLine(n, n2, n + n3 - 1, n2);
            graphics.drawLine(n, n2 + n4 - 1, n, n2 + 1);
            graphics.setColor(this.isRaised ? this.darkShadow : this.lightShadow);
            graphics.drawLine(n + 1, n2 + n4 - 1, n + n3 - 1, n2 + n4 - 1);
            graphics.drawLine(n + n3 - 1, n2 + n4 - 1, n + n3 - 1, n2 + 1);
        }
        
        @Override
        public Insets getBorderInsets(Component component, Insets insets) {
            insets.set(1, 1, 1, 1);
            return insets;
        }
        
        public boolean isOpaque(Component component) {
            return true;
        }
    }
    
    public static class FocusBorder extends AbstractBorder implements UIResource
    {
        private Color focus;
        private Color control;
        
        public FocusBorder(Color control, Color focus) {
            this.control = control;
            this.focus = focus;
        }
        
        @Override
        public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
            if (component.hasFocus()) {
                graphics.setColor(this.focus);
                graphics.drawRect(n, n2, n3 - 1, n4 - 1);
            }
            else {
                graphics.setColor(this.control);
                graphics.drawRect(n, n2, n3 - 1, n4 - 1);
            }
        }
        
        @Override
        public Insets getBorderInsets(Component component, Insets insets) {
            insets.set(1, 1, 1, 1);
            return insets;
        }
    }
    
    public static class ButtonBorder extends AbstractBorder implements UIResource
    {
        protected Color focus;
        protected Color shadow;
        protected Color highlight;
        protected Color darkShadow;
        
        public ButtonBorder(Color shadow, Color highlight, Color darkShadow, Color focus) {
            this.focus = UIManager.getColor("activeCaptionBorder");
            this.shadow = UIManager.getColor("Button.shadow");
            this.highlight = UIManager.getColor("Button.light");
            this.shadow = shadow;
            this.highlight = highlight;
            this.darkShadow = darkShadow;
            this.focus = focus;
        }
        
        @Override
        public void paintBorder(Component component, Graphics graphics, int x, int y, int n, int n2) {
            boolean n3 = false;
            int n4 = 0;
            boolean defaultCapable = false;
            boolean defaultButton = false;
            if ((component instanceof AbstractButton)) {
                AbstractButton abstractButton = (AbstractButton)component;
                ButtonModel model = abstractButton.getModel();
                n3 = (model.isArmed() && model.isPressed());
                n4 = ((model.isArmed() && n3) || (abstractButton.isFocusPainted() && abstractButton.hasFocus()));
                if ((abstractButton instanceof JButton)) {
                    defaultCapable = ((JButton)abstractButton).isDefaultCapable();
                    defaultButton = ((JButton)abstractButton).isDefaultButton();
                }
            }
            int n5 = x + 1;
            int n6 = y + 1;
            int n7 = x + n - 2;
            int n8 = y + n2 - 2;
            if (!(defaultCapable == 0)) {
                if (!(defaultButton == 0)) {
                    graphics.setColor(this.shadow);
                    graphics.drawLine(x + 3, y + 3, x + 3, y + n2 - 4);
                    graphics.drawLine(x + 3, y + 3, x + n - 4, y + 3);
                    graphics.setColor(this.highlight);
                    graphics.drawLine(x + 4, y + n2 - 4, x + n - 4, y + n2 - 4);
                    graphics.drawLine(x + n - 4, y + 3, x + n - 4, y + n2 - 4);
                }
                n5 += 6;
                n6 += 6;
                n7 -= 6;
                n8 -= 6;
            }
            if (n4 != 0) {
                graphics.setColor(this.focus);
                if (!(defaultButton == 0)) {
                    graphics.drawRect(x, y, n - 1, n2 - 1);
                }
                else {
                    graphics.drawRect(n5 - 1, n6 - 1, n7 - n5 + 2, n8 - n6 + 2);
                }
            }
            graphics.setColor(n3 ? this.shadow : this.highlight);
            graphics.drawLine(n5, n6, n7, n6);
            graphics.drawLine(n5, n6, n5, n8);
            graphics.setColor(n3 ? this.highlight : this.shadow);
            graphics.drawLine(n7, n6 + 1, n7, n8);
            graphics.drawLine(n5 + 1, n8, n7, n8);
        }
        
        @Override
        public Insets getBorderInsets(Component component, Insets insets) {
            int n = (component instanceof JButton && ((JButton)component).isDefaultCapable()) ? 8 : 2;
            insets.set(n, n, n, n);
            return insets;
        }
    }
    
    public static class ToggleButtonBorder extends MotifBorders.ButtonBorder
    {
        public ToggleButtonBorder(Color color, Color color2, Color color3, Color color4) {
            super(color, color2, color3, color4);
        }
        
        @Override
        public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
            if ((component instanceof AbstractButton)) {
                AbstractButton abstractButton = (AbstractButton)component;
                ButtonModel model = abstractButton.getModel();
                if ((model.isArmed() && model.isPressed()) || model.isSelected()) {
                    MotifBorders.drawBezel(graphics, n, n2, n3, n4, model.isPressed() || model.isSelected(), abstractButton.isFocusPainted() && abstractButton.hasFocus(), this.shadow, this.highlight, this.darkShadow, this.focus);
                }
                else {
                    MotifBorders.drawBezel(graphics, n, n2, n3, n4, false, abstractButton.isFocusPainted() && abstractButton.hasFocus(), this.shadow, this.highlight, this.darkShadow, this.focus);
                }
            }
            else {
                MotifBorders.drawBezel(graphics, n, n2, n3, n4, false, false, this.shadow, this.highlight, this.darkShadow, this.focus);
            }
        }
        
        @Override
        public Insets getBorderInsets(Component component, Insets insets) {
            insets.set(2, 2, 3, 3);
            return insets;
        }
    }
    
    public static class MenuBarBorder extends MotifBorders.ButtonBorder
    {
        public MenuBarBorder(Color color, Color color2, Color color3, Color color4) {
            super(color, color2, color3, color4);
        }
        
        @Override
        public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
            if (!(component instanceof JMenuBar)) {
                return;
            }
            JMenuBar menuBar = (JMenuBar)component;
            if (menuBar.isBorderPainted()) {
                Dimension size = menuBar.getSize();
                MotifBorders.drawBezel(graphics, n, n2, size.width, size.height, false, false, this.shadow, this.highlight, this.darkShadow, this.focus);
            }
            return;
        }
        
        @Override
        public Insets getBorderInsets(Component component, Insets insets) {
            insets.set(6, 6, 6, 6);
            return insets;
        }
    }
    
    public static class FrameBorder extends AbstractBorder implements UIResource
    {
        JComponent jcomp;
        Color frameHighlight;
        Color frameColor;
        Color frameShadow;
        public static final int BORDER_SIZE = 5;
        
        public FrameBorder(JComponent jcomp) {
            this.jcomp = jcomp;
        }
        
        public void setComponent(JComponent jcomp) {
            this.jcomp = jcomp;
        }
        
        public JComponent component() {
            return this.jcomp;
        }
        
        protected Color getFrameHighlight() {
            return this.frameHighlight;
        }
        
        protected Color getFrameColor() {
            return this.frameColor;
        }
        
        protected Color getFrameShadow() {
            return this.frameShadow;
        }
        
        @Override
        public Insets getBorderInsets(Component component, Insets insets) {
            insets.set(5, 5, 5, 5);
            return insets;
        }
        
        protected boolean drawTopBorder(Component component, Graphics graphics, int x, int y, int width, int n) {
            if (!graphics.getClipBounds().intersects(new Rectangle(x, y, width, 5))) {
                return false;
            }
            int n2 = width - 1;
            int n3 = 4;
            graphics.setColor(this.frameColor);
            graphics.drawLine(x, y + 2, n2 - 2, y + 2);
            graphics.drawLine(x, y + 3, n2 - 2, y + 3);
            graphics.drawLine(x, y + 4, n2 - 2, y + 4);
            graphics.setColor(this.frameHighlight);
            graphics.drawLine(x, y, n2, y);
            graphics.drawLine(x, y + 1, n2, y + 1);
            graphics.drawLine(x, y + 2, x, y + 4);
            graphics.drawLine(x + 1, y + 2, x + 1, y + 4);
            graphics.setColor(this.frameShadow);
            graphics.drawLine(x + 4, y + 4, n2 - 4, y + 4);
            graphics.drawLine(n2, y + 1, n2, n3);
            graphics.drawLine(n2 - 1, y + 2, n2 - 1, n3);
            return true;
        }
        
        protected boolean drawLeftBorder(Component c, Graphics graphics, int n, int n2, int n3, int height) {
            if (!graphics.getClipBounds().intersects(new Rectangle(0, 0, super.getBorderInsets(c).left, height))) {
                return false;
            }
            int n4 = 5;
            graphics.setColor(this.frameHighlight);
            graphics.drawLine(n, n4, n, height - 1);
            graphics.drawLine(n + 1, n4, n + 1, height - 2);
            graphics.setColor(this.frameColor);
            graphics.fillRect(n + 2, n4, n + 2, height - 3);
            graphics.setColor(this.frameShadow);
            graphics.drawLine(n + 4, n4, n + 4, height - 5);
            return true;
        }
        
        protected boolean drawRightBorder(Component c, Graphics graphics, int n, int n2, int n3, int height) {
            if (!graphics.getClipBounds().intersects(new Rectangle(n3 - super.getBorderInsets(c).right, 0, super.getBorderInsets(c).right, height))) {
                return false;
            }
            int n4 = n3 - super.getBorderInsets(c).right;
            int n5 = 5;
            graphics.setColor(this.frameColor);
            graphics.fillRect(n4 + 1, n5, 2, height - 1);
            graphics.setColor(this.frameShadow);
            graphics.fillRect(n4 + 3, n5, 2, height - 1);
            graphics.setColor(this.frameHighlight);
            graphics.drawLine(n4, n5, n4, height - 1);
            return true;
        }
        
        protected boolean drawBottomBorder(Component c, Graphics graphics, int n, int n2, int width, int n3) {
            if (!graphics.getClipBounds().intersects(new Rectangle(0, n3 - super.getBorderInsets(c).bottom, width, super.getBorderInsets(c).bottom))) {
                return false;
            }
            int n4 = n3 - super.getBorderInsets(c).bottom;
            graphics.setColor(this.frameShadow);
            graphics.drawLine(n + 1, n3 - 1, width - 1, n3 - 1);
            graphics.drawLine(n + 2, n3 - 2, width - 2, n3 - 2);
            graphics.setColor(this.frameColor);
            graphics.fillRect(n + 2, n4 + 1, width - 4, 2);
            graphics.setColor(this.frameHighlight);
            graphics.drawLine(n + 5, n4, width - 5, n4);
            return true;
        }
        
        protected boolean isActiveFrame() {
            return this.jcomp.hasFocus();
        }
        
        @Override
        public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
            if (this.isActiveFrame()) {
                this.frameColor = UIManager.getColor("activeCaptionBorder");
            }
            else {
                this.frameColor = UIManager.getColor("inactiveCaptionBorder");
            }
            this.frameHighlight = this.frameColor.brighter();
            this.frameShadow = this.frameColor.darker().darker();
            this.drawTopBorder(component, graphics, n, n2, n3, n4);
            this.drawLeftBorder(component, graphics, n, n2, n3, n4);
            this.drawRightBorder(component, graphics, n, n2, n3, n4);
            this.drawBottomBorder(component, graphics, n, n2, n3, n4);
        }
    }
    
    public static class InternalFrameBorder extends MotifBorders.FrameBorder
    {
        JInternalFrame frame;
        public static final int CORNER_SIZE = 24;
        
        public InternalFrameBorder(JInternalFrame frame) {
            super(frame);
            this.frame = frame;
        }
        
        public void setFrame(JInternalFrame frame) {
            this.frame = frame;
        }
        
        public JInternalFrame frame() {
            return this.frame;
        }
        
        public int resizePartWidth() {
            if (!this.frame.isResizable()) {
                return 0;
            }
            return 5;
        }
        
        @Override
        protected boolean drawTopBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
            if (super.drawTopBorder(component, graphics, n, n2, n3, n4) && this.frame.isResizable()) {
                graphics.setColor(this.getFrameShadow());
                graphics.drawLine(23, n2 + 1, 23, n2 + 4);
                graphics.drawLine(n3 - 24 - 1, n2 + 1, n3 - 24 - 1, n2 + 4);
                graphics.setColor(this.getFrameHighlight());
                graphics.drawLine(24, n2, 24, n2 + 4);
                graphics.drawLine(n3 - 24, n2, n3 - 24, n2 + 4);
                return true;
            }
            return false;
        }
        
        @Override
        protected boolean drawLeftBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
            if (super.drawLeftBorder(component, graphics, n, n2, n3, n4) && this.frame.isResizable()) {
                graphics.setColor(this.getFrameHighlight());
                int n5 = n2 + 24;
                graphics.drawLine(n, n5, n + 4, n5);
                int n6 = n4 - 24;
                graphics.drawLine(n + 1, n6, n + 5, n6);
                graphics.setColor(this.getFrameShadow());
                graphics.drawLine(n + 1, n5 - 1, n + 5, n5 - 1);
                graphics.drawLine(n + 1, n6 - 1, n + 5, n6 - 1);
                return true;
            }
            return false;
        }
        
        @Override
        protected boolean drawRightBorder(Component c, Graphics graphics, int n, int n2, int n3, int n4) {
            if (super.drawRightBorder(c, graphics, n, n2, n3, n4) && this.frame.isResizable()) {
                int n5 = n3 - this.getBorderInsets(c).right;
                graphics.setColor(this.getFrameHighlight());
                int n6 = n2 + 24;
                graphics.drawLine(n5, n6, n3 - 2, n6);
                int n7 = n4 - 24;
                graphics.drawLine(n5 + 1, n7, n5 + 3, n7);
                graphics.setColor(this.getFrameShadow());
                graphics.drawLine(n5 + 1, n6 - 1, n3 - 2, n6 - 1);
                graphics.drawLine(n5 + 1, n7 - 1, n5 + 3, n7 - 1);
                return true;
            }
            return false;
        }
        
        @Override
        protected boolean drawBottomBorder(Component c, Graphics graphics, int n, int n2, int n3, int n4) {
            if (super.drawBottomBorder(c, graphics, n, n2, n3, n4) && this.frame.isResizable()) {
                int n5 = n4 - this.getBorderInsets(c).bottom;
                graphics.setColor(this.getFrameShadow());
                graphics.drawLine(23, n5 + 1, 23, n4 - 1);
                graphics.drawLine(n3 - 24, n5 + 1, n3 - 24, n4 - 1);
                graphics.setColor(this.getFrameHighlight());
                graphics.drawLine(24, n5, 24, n4 - 2);
                graphics.drawLine(n3 - 24 + 1, n5, n3 - 24 + 1, n4 - 2);
                return true;
            }
            return false;
        }
        
        @Override
        protected boolean isActiveFrame() {
            return this.frame.isSelected();
        }
    }
    
    public static class MotifPopupMenuBorder extends AbstractBorder implements UIResource
    {
        protected Font font;
        protected Color background;
        protected Color foreground;
        protected Color shadowColor;
        protected Color highlightColor;
        protected static final int TEXT_SPACING = 2;
        protected static final int GROOVE_HEIGHT = 2;
        
        public MotifPopupMenuBorder(Font font, Color background, Color foreground, Color shadowColor, Color highlightColor) {
            this.font = font;
            this.background = background;
            this.foreground = foreground;
            this.shadowColor = shadowColor;
            this.highlightColor = highlightColor;
        }
        
        @Override
        public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
            if (!(component instanceof JPopupMenu)) {
                return;
            }
            Font font = graphics.getFont();
            Color color = graphics.getColor();
            JPopupMenu c = (JPopupMenu)component;
            String label = c.getLabel();
            if (label == null) {
                return;
            }
            graphics.setFont(this.font);
            FontMetrics fontMetrics = SwingUtilities2.getFontMetrics(c, graphics, this.font);
            int height = fontMetrics.getHeight();
            int descent = fontMetrics.getDescent();
            int ascent = fontMetrics.getAscent();
            Point point = new Point();
            int stringWidth = SwingUtilities2.stringWidth(c, fontMetrics, label);
            point.y = n2 + ascent + 2;
            point.x = n + (n3 - stringWidth) / 2;
            graphics.setColor(this.background);
            graphics.fillRect(point.x - 2, point.y - (height - descent), stringWidth + 4, height - descent);
            graphics.setColor(this.foreground);
            SwingUtilities2.drawString(c, graphics, label, point.x, point.y);
            MotifGraphicsUtils.drawGroove(graphics, n, point.y + 2, n3, 2, this.shadowColor, this.highlightColor);
            graphics.setFont(font);
            graphics.setColor(color);
            return;
        }
        
        @Override
        public Insets getBorderInsets(Component component, Insets insets) {
            if (!(component instanceof JPopupMenu)) {
                return insets;
            }
            int descent = 0;
            int ascent = 16;
            if (((JPopupMenu)component).getLabel() == null) {
                int n = 0;
                insets.bottom = n;
                insets.right = n;
                insets.top = n;
                insets.left = n;
                return insets;
            }
            FontMetrics fontMetrics = component.getFontMetrics(this.font);
            if (fontMetrics != null) {
                descent = fontMetrics.getDescent();
                ascent = fontMetrics.getAscent();
            }
            insets.top += ascent + descent + 2 + 2;
            return insets;
        }
    }
}
